[PATCH 4/4] media: au0828 change vidioc_s_input() to call v4l_change_media_source()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Change vidioc_s_input() to call v4l_change_media_source() to disable
current source and enable new source when user switches input.

Signed-off-by: Shuah Khan <shuahkh@xxxxxxxxxxxxxxx>
---
 drivers/media/usb/au0828/au0828-video.c | 8 +++-----
 1 file changed, 3 insertions(+), 5 deletions(-)

diff --git a/drivers/media/usb/au0828/au0828-video.c b/drivers/media/usb/au0828/au0828-video.c
index aeaf27e..020c9d5 100644
--- a/drivers/media/usb/au0828/au0828-video.c
+++ b/drivers/media/usb/au0828/au0828-video.c
@@ -1545,12 +1545,10 @@ static int vidioc_s_input(struct file *file, void *priv, unsigned int index)
 	au0828_s_input(dev, index);
 
 	/*
 	 * Input has been changed. Disable the media source
 	 * associated with the old input and enable source
 	 * for the newly set input
 	 */
-	v4l_disable_media_source(vfd);
-	return v4l_enable_media_source(vfd);
+	return v4l_change_media_source(vfd);
 }
 
 static int vidioc_enumaudio(struct file *file, void *priv, struct v4l2_audio *a)
@@ -1545,12 +1545,10 @@ static int vidioc_s_input(struct file *file, void *priv, unsigned int index)
 
 	/*
-	 * Input has been changed. Disable the media source
-	 * associated with the old input and enable source
-	 * for the newly set input
+	 * Input has been changed. Change to media source
+	 * associated with the for the newly set input.
 	 */
-- 
2.5.0

--
To unsubscribe from this list: send the line "unsubscribe linux-media" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html



[Index of Archives]     [Linux Input]     [Video for Linux]     [Gstreamer Embedded]     [Mplayer Users]     [Linux USB Devel]     [Linux Audio Users]     [Linux Kernel]     [Linux SCSI]     [Yosemite Backpacking]
  Powered by Linux